@@ -4,7 +4,7 @@ import os
 from functools import lru_cache
 from importlib import import_module
 from pathlib import Path
-from typing import List, Optional, Set, Tuple, Union, cast
+from typing import Iterable, List, Optional, Set, Tuple, Union, cast
 
 from . import iou, pathu, regexu, scan
 from ._exceptions import (
@@ -69,11 +69,13 @@ class Refactor:
         self._import_stats = scan.ImportStats(set(), set())
         self._source_stats = scan.SourceStats(set(), set(), set())
         self._path = Path("")
+        self._is_init_without_all = False
 
     def _reset(self) -> None:
         self._import_stats = scan.ImportStats(set(), set())
         self._source_stats = scan.SourceStats(set(), set(), set())
         self._path = Path("")
+        self._is_init_without_all = False
 
     @staticmethod
     def remove_useless_passes(source_lines: List[str]) -> List[str]:
@@ -82,16 +84,48 @@ class Refactor:
         :param source_lines: source code lines.
         :returns: clean source code lines.
         """
+
+        def remove_from_children(
+            parent: ast.AST, children: Iterable, body_len: int, wl: Set[ast.AST]
+        ):
+            #: Remove any `ast.Pass` node
+            #: that is both useless and not in the `wl` (white list).
+            #:
+            #: The below case is not going to be touched:
+            #:
+            #: >>> (async) (def) (class) foo:
+            #: >>>      """DOCString"""
+            #: >>>      pass
+            #:
+            for child in children:
+                if isinstance(child, ast.Pass):
+                    if child not in wl:
+                        if isinstance(
+                            parent,
+                            (ast.AsyncFunctionDef, ast.FunctionDef, ast.ClassDef),
+                        ):
+                            if body_len == 2 and ast.get_docstring(parent):
+                                break
+                        if body_len > 1:
+                            body_len -= 1
+                            source_lines[child.lineno - 1] = ""
+
         tree = ast.parse("".join(source_lines))
         for parent in ast.walk(tree):
+
             body = getattr(parent, "body", None)
             if body and hasattr(body, "__len__"):
                 body_len = len(body)
-            for child in ast.iter_child_nodes(parent):
-                if isinstance(child, ast.Pass):
-                    if body_len > 1:
-                        body_len -= 1
-                        source_lines[child.lineno - 1] = ""
+                white_list: Set[ast.AST] = set()
+
+                if hasattr(parent, "orelse"):
+                    orelse = getattr(parent, "orelse")
+                    remove_from_children(parent, orelse, len(orelse), white_list)
+                    white_list = set(orelse)
+
+                children = ast.iter_child_nodes(parent)
+                remove_from_children(parent, children, body_len, white_list)
+
         return "".join(source_lines).splitlines(True)
 
     def session(self, path: Path) -> None:
@@ -184,9 +218,11 @@ class Refactor:
             analyzer.visit(tree)
             source_stats, import_stats = analyzer.get_stats()
 
+            #: `__init__.py` file with no `__all__` dunder issue:
+            #:
+            #: PR/ISSUE/DOC Ref: https://github.com/hadialqattan/pycln/pull/97
             if regexu.is_init_file(self._path) and not analyzer.has_all():
-                self.reporter.init_without_all_warning(self._path)
-                return None
+                self._is_init_without_all = True
 
             return source_stats, import_stats
         except Exception as err:
@@ -221,6 +257,15 @@ class Refactor:
                 # Get set of used names.
                 used_names = self._get_used_names(node, is_star)
 
+                used_names_len = len(used_names)
+                node_names_len = len(node.names)
+
+                if self._is_init_without_all and (
+                    is_star or used_names_len != node_names_len
+                ):
+                    self.reporter.init_without_all_warning(self._path)
+                    break
+
                 # Depends on `--expand-stars, -x` option.
                 if is_star:
                     if used_names:
@@ -232,7 +277,7 @@ class Refactor:
                         self.reporter.removed_import(self._path, node, star_alias)
 
                 # No alias has removed/added.
-                if used_names and len(used_names) == len(node.names):
+                if used_names and used_names_len == node_names_len:
                     if not self.configs.expand_stars:
                         continue
 
@@ -245,6 +290,10 @@ class Refactor:
                 fixed_lines = self._transform(
                     node.location, used_names, original_lines, fixed_lines
                 )
+            else:
+                continue
+
+            break
 
         return "".join(fixed_lines)
 
@@ -254,7 +303,7 @@ class Refactor:
         """Get set of used names base on given `node` and `self._source_stats`.
 
         :param node: import node to names check.
-        :parma is_star: is '*' import node.
+        :param is_star: is '*' import node.
         :returns: set of used names.
         """
         used_names: Set[str] = set()
@@ -262,7 +311,7 @@ class Refactor:
             if self._should_remove(
                 node, alias, is_star
             ) and not self._is_partially_used(alias, is_star):
-                if not is_star:
+                if not (is_star or self._is_init_without_all):
                     self.reporter.removed_import(self._path, node, alias)
                 continue
             used_names.add(alias.name)
